@@ -123,6 +123,10 @@ The DONE message indicates that ghostscript has finished processing.
 #include "gtkgs.h"
 #include "file.h"
 
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #define NON_BLOCKING_IO
 #ifdef NON_BLOCKING_IO
 #include <fcntl.h>
@@ -207,8 +211,8 @@ gtk_gs_init (GtkGS *gs)
         gs->height = -1;
         gs->busy      = FALSE;
         gs->changed   = FALSE;
-        gs->gs_scan_pdf_cmd = GS_PATH " -dNODISPLAY -dQUIET -sPDFname=%s -sDSCname=%s pdf2dsc.ps -c quit";
-        gs->gs_uncompress_cmd = "gzip -cd %s > %s";
+        gs->gs_scan_pdf_cmd = GS_PATH " -dNODISPLAY -dQUIET -sPDFname=\"%s\" -sDSCname=%s pdf2dsc.ps -c quit";
+        gs->gs_uncompress_cmd = "gzip -cd \"%s\" > \"%s\"";
         gs->gs_scanstyle = 0;
 	gs->gs_filename_raw = 0;
 	gs->gs_filename_dsc = 0;
@@ -308,32 +312,32 @@ gtk_gs_cleanup (GtkGS *gs)
 
         stop_interpreter(gs);
 
-        if (gs->gs_filename)
+	if (gs->gs_filename) {
                 g_free(gs->gs_filename);
-        if (gs->gs_filename_raw)
+		gs->gs_filename = NULL;
+	}
+	if (gs->gs_filename_raw) {
                 g_free(gs->gs_filename_raw);
-        if (gs->doc)
+		gs->gs_filename_raw = NULL;
+	}
+	if (gs->doc) {
                 psfree(gs->doc);
+		gs->doc = NULL;
+	}
         if (gs->gs_filename_dsc){
-                /*
-                g_print("Removing dsc temp file: %s\n", gs->gs_filename_dsc);
-                */
                 unlink(gs->gs_filename_dsc);
+                g_free(gs->gs_filename_dsc);
                 gs->gs_filename_dsc = NULL;
         }
         if (gs->gs_filename_unc){
-                /*
-                g_print("Removing unc temp file: %s\n", gs->gs_filename_unc);
-                */
                 unlink(gs->gs_filename_unc);
+                g_free(gs->gs_filename_unc);
                 gs->gs_filename_unc = NULL;
         }
         if (gs->pages_marked) {
                 g_free(gs->pages_marked);
                 gs->pages_marked = NULL;
         }
-        gs->doc = NULL;
-  
 }
 
 static void
@@ -352,7 +356,6 @@ gtk_gs_destroy (GtkObject *object)
                 (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-
 /* FIXME: I'm not sure if all this is supposed to be here 
  * this is just a quick hack so that this can be called whenever
  * something changes.
@@ -656,6 +659,9 @@ set_up_page (GtkGS *gs)
         char               buf[1024];
         GdkPixmapPrivate  *pprivate;
         gint w, h;
+#ifdef HAVE_SETLOCALE
+        char *savelocale;
+#endif
 
         /* Do we have to check if the actual geometry changed? */
         
@@ -702,6 +708,13 @@ set_up_page (GtkGS *gs)
                 */
         }
 
+#ifdef HAVE_SETLOCALE
+        /* gs needs floating point parameters with '.' as decimal point
+         * while some (european) locales use ',' instead, so we set the 
+         * locale for this snprintf to "C".
+         */
+        savelocale = setlocale (LC_NUMERIC, "C");
+#endif
         pprivate = (GdkPixmapPrivate *) gs->bpixmap;
         snprintf(buf, 1024, "%ld %d %d %d %d %d %f %f %d %d %d %d",
                  (pprivate ? pprivate->xwindow : 0L),
@@ -714,7 +727,9 @@ set_up_page (GtkGS *gs)
                  gs->bottom_margin,
                  gs->right_margin,
                  gs->top_margin);
-        /*        g_print("Sent to PostScript %s\n",buf); */
+#ifdef HAVE_SETLOCALE
+        setlocale (LC_NUMERIC, savelocale);
+#endif
         gdk_property_change(gs->pstarget,
                             gs_class->gs_atom,
                             gs_class->string_atom,
@@ -845,7 +860,7 @@ input (gpointer data, gint source, GdkInputCondition condition)
                 }
 
                 if (gs->buffer_bytes_left > 0) {
-                        /*                        g_print (" writing: %s\n",gs->input_buffer_ptr);*/
+                        /* g_print (" writing: %s\n",gs->input_buffer_ptr); */
                         
                         bytes_written = write(gs->interpreter_input,
                                               gs->input_buffer_ptr,
@@ -912,15 +927,12 @@ start_interpreter (GtkGS *gs)
         /* I assume we do _not_ want to change this... (: */
         argv[argc++] = "-dSAFER";
 
-
         /* set up the pipes */
-
-
-
-
         if (gs->send_filename_to_gs && !gs->reading_from_pipe) {
-                
-                argv[argc++] = gs->gs_filename;
+                if(gs->gs_filename_unc)
+                        argv[argc++] = gs->gs_filename_unc;
+                else
+                        argv[argc++] = gs->gs_filename;
                 argv[argc++] = "-c";
                 argv[argc++] = "quit";
         }
@@ -929,7 +941,6 @@ start_interpreter (GtkGS *gs)
    
         argv[argc++] = NULL;
 
-
         if (gs->send_filename_to_gs && !gs->reading_from_pipe) {
                 ret = pipe(std_in);
                 if (ret == -1) {
@@ -1158,6 +1169,9 @@ gtk_gs_load (GtkGS *gs, char *fname)
         struct stat sbuf;
 	int i;
 	g_assert(gs != NULL);
+
+        gtk_gs_cleanup(gs);
+
 	if (fname == NULL) {
                 if(gdk_window_is_visible(gs->pstarget))
                         gdk_window_hide(gs->pstarget);
@@ -1170,8 +1184,6 @@ gtk_gs_load (GtkGS *gs, char *fname)
 
 		/* clean up previous document */
 
-                gtk_gs_cleanup(gs);
-
 		/* prepare this document */
 		if ((gs->gs_psfile = fopen(fname, "r")) == NULL)
                         return FALSE;
@@ -1224,6 +1236,8 @@ gtk_gs_load (GtkGS *gs, char *fname)
                         */
                         gs->structured_doc = FALSE; 
                         gs->send_filename_to_gs = TRUE;
+
+                        return FALSE;
                 }
 
                 /*
