@@ -316,7 +316,7 @@ gboolean load_gs(ggv_window *ggv, char *fname)
                 gtk_widget_set_sensitive (ggv->printitem, FALSE);
                 gtk_widget_set_sensitive (ggv->printmarked, FALSE);
                 gtk_widget_set_sensitive (ggv->save, FALSE);
-                gtk_widget_set_sensitive (ggv->saveas, FALSE);
+                /*                gtk_widget_set_sensitive (ggv->saveas, FALSE); */
                 gtk_widget_set_sensitive (ggv->toggleakt, FALSE);
                 gtk_widget_set_sensitive (ggv->toggleall, FALSE);
                 gtk_widget_set_sensitive (ggv->toggleeven, FALSE);
@@ -390,10 +390,10 @@ gboolean load_gs(ggv_window *ggv, char *fname)
         gtk_widget_set_sensitive(ggv->printmarked, is_structured);
         gtk_widget_set_sensitive(ggv->reloaditem, TRUE);
         gtk_widget_set_sensitive(ggv->save, is_structured);
-#if 0
-        /* this is not implemented yet */
-        gtk_widget_set_sensitive(ggv->saveas, TRUE);
-#endif
+
+        /* this is not implemented yet 
+           gtk_widget_set_sensitive(ggv->saveas, TRUE); */
+
         set_page_sensitivities(ggv, page);
 
         gtk_widget_set_sensitive (ggv->toggleakt, is_structured);
@@ -425,9 +425,16 @@ void save_marked_pages(ggv_window *ggv, gchar *file)
                 gtk_gs_count_marked_pages(GTK_GS(ggv->gs)));
 
         if((file_handle = fopen(file, "w")) != NULL) {
-                pscopydoc(file_handle, GTK_GS (ggv->gs)->gs_filename,
+
+                if (GTK_GS (ggv->gs)->gs_filename_unc != NULL)
+                        /* Use uncompress file */
+                        pscopydoc(file_handle, GTK_GS (ggv->gs)->gs_filename_unc,
                           GTK_GS(ggv->gs)->doc, 
-                          GTK_GS(ggv->gs)->pages_marked);
+                          GTK_GS(ggv->gs)->pages_marked); 
+                else
+                        pscopydoc(file_handle, GTK_GS (ggv->gs)->gs_filename,
+                                  GTK_GS(ggv->gs)->doc, 
+                                  GTK_GS(ggv->gs)->pages_marked);
                 flash = g_strdup_printf(_("Successfully saved marked pages to file %s."), file);
                 flash_message(ggv, flash);
         }
@@ -671,8 +678,10 @@ void create_menus(ggv_window *retval, window_with_data *temp)
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PRINT, 0, 0, NULL },
                 {GNOME_APP_UI_ITEM, N_("Save _marked pages..."), N_("Save marked pages to a new file"), save_callback, retval, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL},
+                /* Not implemented yet 
                 {GNOME_APP_UI_ITEM, N_("Save _As..."), N_("Save document to a new file"), save_as_callback, retval, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL},
+                */
                 {GNOME_APP_UI_SEPARATOR},
                 {GNOME_APP_UI_ITEM, N_("_Close"), N_("Close this window"), close_callback, retval, NULL,
                  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE, 'w', GDK_CONTROL_MASK, NULL },
@@ -735,7 +744,9 @@ void create_menus(ggv_window *retval, window_with_data *temp)
         retval->printitem = fileMenu[4].widget;
         retval->printmarked = fileMenu[5].widget;
         retval->save = fileMenu[6].widget;
+        /*
         retval->saveas = fileMenu[7].widget;
+        */
         retval->menus_vis = settingsMenu[2].widget;
         retval->panel_vis = settingsMenu[3].widget;
         retval->toggleakt = documentMenu[4].widget;
@@ -750,7 +761,7 @@ void create_menus(ggv_window *retval, window_with_data *temp)
         gtk_widget_set_sensitive (GTK_WIDGET(retval->printmarked), FALSE);
         gtk_widget_set_sensitive (GTK_WIDGET(retval->reloaditem), FALSE);
         gtk_widget_set_sensitive (GTK_WIDGET(retval->save), FALSE);
-        gtk_widget_set_sensitive (GTK_WIDGET(retval->saveas), FALSE);
+        /*        gtk_widget_set_sensitive (GTK_WIDGET(retval->saveas), FALSE); */
         gtk_widget_set_sensitive (GTK_WIDGET(retval->toggleakt), FALSE);
         gtk_widget_set_sensitive (GTK_WIDGET(retval->toggleall), FALSE);
         gtk_widget_set_sensitive (GTK_WIDGET(retval->toggleeven), FALSE);
