@@ -1523,16 +1523,7 @@ pscopy(from, to, begin, end)
  *		       comments are encountered.
  */
 
-char *
-pscopyuntil(from, to, begin, end, comment)
-    FILE *from;
-    FILE *to;
-    long begin;			/* set negative to avoid initial seek */
-    long end;
-#if NeedFunctionPrototypes
-    const
-#endif
-    char *comment;
+char *pscopyuntil(FILE *from, FILE *to, long begin, long end, const char *comment)
 {
     char line[PSLINELENGTH];	/* 255 characters + 1 newline + 1 NULL */
     char text[PSLINELENGTH];	/* Temporary storage for text */
@@ -1549,7 +1540,7 @@ pscopyuntil(from, to, begin, end, comment)
       comment_length = 0;
     if (begin >= 0) fseek(from, begin, SEEK_SET);
 
-    while (ftell(from) < end) {
+    while (ftell(from) < end && !feof(from)) {
 	fgets(line, sizeof line, from);
 
 	/* iscomment cannot be used here,
